@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from collections.abc import Iterator, Mapping
-from typing import Union
+from typing import Optional, Union
 
 from rflx.common import Base
 from rflx.identifier import StrID
@@ -20,7 +20,7 @@ class Package(Base):
         return self._name
 
     def new_message(
-        self, key: StrID, parameters: Mapping[str, Union[bool, int, str]] = None
+        self, key: StrID, parameters: Optional[Mapping[str, Union[bool, int, str]]] = None
     ) -> MessageValue:
         message = self._messages[str(key)].clone()
         if parameters:
